#!/bin/sh

#
# Check installed Java package
#
check_java_package ()
{
	# check java sdk package (alternatives, java-config were installed)
	local JAVA_NAME="$(rpm -q --qf '%{NAME}\n' ${JAVA_SDK}|grep '^java')"
#	echo $JAVA_NAME
	if [ "${JAVA_NAME}x" != "${JAVA_SDK}x" ] ; then
		echo "--------------------------------------------------------------------------------"
		echo "ERROR"
		echo " Java SDK Package Not Found."
		echo " Please Install \"java-sun-j2se1.5-sdk\"."
		echo "--------------------------------------------------------------------------------"
		exit
	fi

	# check license file
	DLJ_FILE="$(rpm -ql ${JAVA_SDK}|grep DLJ)"
#	echo $DLJ_FILE
	if [ ! -f "${DLJ_FILE}" ] ; then
		echo "--------------------------------------------------------------------------------"
		echo "ERROR"
		echo " License File Not Found."
		echo " Please Install \"${JAVA_SDK}\"."
		echo "--------------------------------------------------------------------------------"
		exit
	fi
}

#
# Check already java enable ?
#
check_already_enable ()
{
	local JAVA_ALREADY_ENABLE="$( alternatives --display java )"
	if [ -n "${JAVA_ALREADY_ENABLE}" ] ; then
		echo "Java SDK is already enable."
		exit
	fi
}


#
# Check for root access
#
check_super_user ()
{
	if [ "${USER}x" != "rootx" ] ; then
		if [ ! -w /dev ] ; then
			echo "--------------------------------------------------------------------------------"
			echo "WARNING"
			echo " You are not login as root."
			echo " Superuser privileges are required setting of Java SDK."
			echo "--------------------------------------------------------------------------------"
			echo
			echo -n "Please enter \"root\" "
			exec su -c "/bin/sh ${SCRIPT}"
			echo ""
		fi
	fi
}

#
# Show DLJ (Distributor License for Java)
#
show_dlj ()
{
	clear ; echo; echo " Momonga Linux Sun Java SDK Setup" ;echo
	echo "--------------------------------------------------------------------------------"
	echo " IMPORTANT : "
	echo " Please carefully read the following terms and conditions before using JDK.";echo
	echo "--------------------------------------------------------------------------------"
	echo -n "Press Enter to continue. : "
	read CONTINUE &> /dev/null
	echo
	more "$DLJ_FILE"
	echo "--------------------------------------------------------------------------------"
	echo 
	echo "Do you agree to be bound by the terms and conditions of this license agreement?"
	echo 
}


#
# Get user acceptance for licenses.
#
get_acceptance ()
{
	echo
	echo -n "'accept' to continue, 'reject' to quit.  :   "
	read ACCEPTANCE &> /dev/null
	
	# delete space
	ACCEPTANCE="$(echo $ACCEPTANCE | sed -e'1,$s/ *$//g')"
	ACCEPTANCE="$(echo $ACCEPTANCE | sed -e'1,$s/[[:space:]]*$//g' )"

	if echo "$ACCEPTANCE" | grep -i '^reject$' &> /dev/null ; then
		exit
	elif ! echo "$ACCEPTANCE" | grep -i '^accept$' &> /dev/null ; then
		get_acceptance
	fi
}


#
# Enable Java
#
enable_java_sdk ()
{
	$JAVACONFIG --quiet --install-alternatives $ALTERNATIVES_DIR/${SDK_BASENAME}.java
	$JAVACONFIG --quiet --install-alternatives $ALTERNATIVES_DIR/${SDK_BASENAME}.javac
	echo "--------------------------------------------------------------------------------"
	echo " Enable Java SDK"
	echo "--------------------------------------------------------------------------------"
}



SCRIPT="$0"
SCRIPT_ARGS="$@"
ARGS_NUM="$#"

JAVA_SDK="java-sun-j2se1.5-sdk"
DLJ_FILE=""
ALTERNATIVES_DIR="/etc/java/alternatives"
SDK_BASENAME="sun-j2se1.5-sdk"
JAVACONFIG="/usr/bin/java-config"


#
# main
# 

check_java_package
check_already_enable 
check_super_user
show_dlj
get_acceptance
enable_java_sdk

